@@ -15,7 +15,7 @@ from office365.directory.directory_object_collection import DirectoryObjectColle
 from office365.directory.licenses.license_details import LicenseDetails
 from office365.directory.identities.object_identity import ObjectIdentity
 from office365.directory.profile_photo import ProfilePhoto
-from office365.entity_collection import EntityCollection
+from office365.entity_collection import EntityCollection, DeltaCollection
 from office365.outlook.contacts.contact import Contact
 from office365.outlook.contacts.contact_folder import ContactFolder
 from office365.outlook.mail.mail_folder import MailFolder
@@ -28,7 +28,7 @@ from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.teams.team_collection import TeamCollection
 from office365.teams.user_teamwork import UserTeamwork
 
@@ -315,28 +315,28 @@ class User(DirectoryObject):
         """Get a contact collection from the default Contacts folder of the signed-in user (.../me/contacts),
         or from the specified contact folder."""
         return self.properties.get('contacts',
-                                   EntityCollection(self.context, Contact,
-                                                    ResourcePath("contacts", self.resource_path)))
+                                   DeltaCollection(self.context, Contact,
+                                                   ResourcePath("contacts", self.resource_path)))
 
     @property
     def contact_folders(self):
         """Get the contact folder collection in the default Contacts folder of the signed-in user."""
         return self.properties.get('contactFolders',
-                                   EntityCollection(self.context, ContactFolder,
-                                                    ResourcePath("contactFolders", self.resource_path)))
+                                   DeltaCollection(self.context, ContactFolder,
+                                                   ResourcePath("contactFolders", self.resource_path)))
 
     @property
     def events(self):
         """Get an event collection or an event."""
-        return self.properties.get('events', EntityCollection(self.context, Event,
-                                                              ResourcePath("events", self.resource_path)))
+        return self.properties.get('events', DeltaCollection(self.context, Event,
+                                                             ResourcePath("events", self.resource_path)))
 
     @property
     def messages(self):
         """Get an event collection or an event."""
         return self.properties.get('messages',
-                                   EntityCollection(self.context, Message,
-                                                    ResourcePath("messages", self.resource_path)))
+                                   DeltaCollection(self.context, Message,
+                                                   ResourcePath("messages", self.resource_path)))
 
     @property
     def joined_teams(self):
@@ -363,8 +363,8 @@ class User(DirectoryObject):
     def mail_folders(self):
         """Get the mail folder collection under the root folder of the signed-in user. """
         return self.properties.get('mailFolders',
-                                   EntityCollection(self.context, MailFolder,
-                                                    ResourcePath("mailFolders", self.resource_path)))
+                                   DeltaCollection(self.context, MailFolder,
+                                                   ResourcePath("mailFolders", self.resource_path)))
 
     @property
     def outlook(self):
