@@ -1,13 +1,14 @@
 from office365.runtime.client_value import ClientValue
-from office365.runtime.odata.json_light_format import JsonLightFormat
+from office365.runtime.odata.odata_type import ODataType
+from office365.runtime.odata.v3.json_light_format import JsonLightFormat
 
 
 class ClientValueCollection(ClientValue):
 
     def __init__(self, item_type, initial_values=None):
         """
-        :type item_type: any
-        :type initial_values: any
+        :type item_type: type[ClientValue] or type[int] or type[str]
+        :type initial_values: list or dict or None
         """
         super(ClientValueCollection, self).__init__()
         if initial_values is None:
@@ -18,6 +19,14 @@ class ClientValueCollection(ClientValue):
     def add(self, value):
         self._data.append(value)
 
+    def __getitem__(self, index):
+        """
+
+        :type index: int
+        :rtype: ClientValue
+        """
+        return self._data[index]
+
     def __iter__(self):
         for item in self._data:
             yield item
@@ -29,16 +38,14 @@ class ClientValueCollection(ClientValue):
         """
         :type json_format: office365.runtime.odata.odata_json_format.ODataJsonFormat or None
         """
-        json_items = [item for item in self._data]
-        for i, v in enumerate(json_items):
+        json = [item for item in self._data]
+        for i, v in enumerate(json):
             if isinstance(v, ClientValue):
-                json_items[i] = v.to_json(json_format)
-        if isinstance(json_format, JsonLightFormat) and json_format.is_verbose:
-            json = {json_format.collection_tag_name: json_items,
+                json[i] = v.to_json(json_format)
+        if isinstance(json_format, JsonLightFormat) and json_format.include_control_information():
+            json = {json_format.collection_tag_name: json,
                     json_format.metadata_type_tag_name: {'type': self.entity_type_name}}
-
-            return json
-        return json_items
+        return json
 
     def set_property(self, index, value, persist_changes=False):
         child_value = self._item_type()
@@ -48,23 +55,15 @@ class ClientValueCollection(ClientValue):
         else:
             child_value = value
         self.add(child_value)
+        return self
 
     @property
     def entity_type_name(self):
-        """
-        Gets server type name
-        """
-        primitive_types = {
-            bool: "Edm.Boolean",
-            int: "Edm.Int32",
-            str: "Edm.String",
-        }
-
         item_type_name = None
 
-        is_primitive = primitive_types.get(self._item_type, None) is not None
+        is_primitive = ODataType.primitive_types.get(self._item_type, None) is not None
         if is_primitive:
-            item_type_name = primitive_types[self._item_type]
+            item_type_name = ODataType.primitive_types[self._item_type]
         elif issubclass(self._item_type, ClientValue):
             item_type_name = self._item_type.entity_type_name.fget(self)
 
